==> haskell-regex-applicative-text-0.1.0.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative-text
version: 0.1.0.1
id: regex-applicative-text-0.1.0.1-IbMjwcdL4y8DudMOwbio0X
key: regex-applicative-text-0.1.0.1-IbMjwcdL4y8DudMOwbio0X
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/regex-applicative-text#readme
synopsis: regex-applicative on text
description:
    Wrapped regex-applicative primitives to work with Text
category: Text
abi: bdc1e6a6e7ef8b01577066914809caf7
exposed: True
exposed-modules:
    Text.Regex.Applicative.Text
import-dirs: /usr/lib/ghc-8.6.3/site-local/regex-applicative-text-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/regex-applicative-text-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/regex-applicative-text-0.1.0.1
hs-libraries: HSregex-applicative-text-0.1.0.1-IbMjwcdL4y8DudMOwbio0X
depends:
    base-4.12.0.0 regex-applicative-0.3.3-I3rRNj55s533YYKiqKRdUu
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative-text
version: 0.1.0.1
id: regex-applicative-text-0.1.0.1-6cTcEmuiw6yEWPxf8X9cyP
key: regex-applicative-text-0.1.0.1-6cTcEmuiw6yEWPxf8X9cyP
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/regex-applicative-text#readme
synopsis: regex-applicative on text
description:
    Wrapped regex-applicative primitives to work with Text
category: Text
abi: 473297f5440de9b84541cd3c9e98ecec
exposed: True
exposed-modules:
    Text.Regex.Applicative.Text
import-dirs: /usr/lib/ghc-8.6.4/site-local/regex-applicative-text-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/regex-applicative-text-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/regex-applicative-text-0.1.0.1
hs-libraries: HSregex-applicative-text-0.1.0.1-6cTcEmuiw6yEWPxf8X9cyP
depends:
    base-4.12.0.0 regex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
